/**
 * Copyright (c) 2007-2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.databinding.jaxb.service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.xml.namespace.QName;

import org.ow2.petals.databinding.jaxb.Registry;
import org.ow2.petals.databinding.jaxb.serialization.ServiceMarshaller;
import org.ow2.petals.databinding.jaxb.serialization.ServiceUnmarshaller;

/**
 * @author Mohammed EL JAI - EBM WebSourcing
 */
public class Service {
	
	/** **/
	private ServiceMarshaller serviceMarshaller;

	/** **/
	private ServiceUnmarshaller serviceUnmarshaller;
	
	/**  **/
	private List<Operation> serviceOperations;

	/**  **/
	private String endpoint;

	/**  **/
	private QName serviceName;

	/**  **/
	private QName interfaceName;
	
	/** **/
	private Map<String, String> classPackageMapping;
	
	/** **/
	private Registry registry;
	
	/**
	 * 
	 *
	 */
	public Service() {
		super();
		this.serviceOperations = new ArrayList<Operation>();
	}

	/**
	 * 
	 * @param operationName
	 * @return
	 */
	public Operation getOperationByName(String operationName) {
	    
		for (Operation serviceOperation : serviceOperations) {
			if (serviceOperation.getOperationName().equals(operationName) ||
			        (serviceOperation.getSoapActionName() != null 
			                && serviceOperation.getSoapActionName().equals(operationName))) {
				return serviceOperation;
			}
		}
		
		// The case when the operation name start with an upper case 
		// (some wsdl2java tools generate operation name with a lower case)
		for (Operation serviceOperation : serviceOperations) {
            if (serviceOperation.getOperationName().equalsIgnoreCase(operationName) ||
                    (serviceOperation.getSoapActionName() != null 
                            && serviceOperation.getSoapActionName().equals(operationName))) {
                return serviceOperation;
            }
        }

		return null;
	}
	

	public ServiceMarshaller getServiceMarshaller() {
		return serviceMarshaller;
	}

	public void setServiceMarshaller(ServiceMarshaller serviceMarshaller) {
		this.serviceMarshaller = serviceMarshaller;
	}

	public ServiceUnmarshaller getServiceUnmarshaller() {
		return serviceUnmarshaller;
	}

	public void setServiceUnmarshaller(ServiceUnmarshaller serviceUnmarshaller) {
		this.serviceUnmarshaller = serviceUnmarshaller;
	}
	
	public List<Operation> getOperations() {
		return serviceOperations;
	}

	public void setOperations(List<Operation> operations) {
		this.serviceOperations = operations;
	}

	public String getEndpoint() {
		return endpoint;
	}

	public void setEndpoint(String endpoint) {
		this.endpoint = endpoint;
	}

	public QName getServiceName() {
		return serviceName;
	}

	public void setServiceName(QName serviceName) {
		this.serviceName = serviceName;
	}

	public QName getInterfaceName() {
		return interfaceName;
	}

	public void setInterfaceName(QName interfaceName) {
		this.interfaceName = interfaceName;
	}


	public List<Operation> getServiceOperations() {
		return serviceOperations;
	}


	public void setServiceOperations(List<Operation> serviceOperations) {
		this.serviceOperations = serviceOperations;
	}

	public void addClassMapping(String className, String packageName){
        if (this.classPackageMapping == null)
        {
            this.classPackageMapping = new HashMap<String,String>();
        }
        this.classPackageMapping.put(className, packageName);        
    }

    public Map<String, String> getClassPackageMapping() {
        return classPackageMapping;
    }

    public void setRegistry(Registry registry) {
        this.registry = registry;
    }

    public Registry getRegistry() {
        return registry;
    }

}
